package com.exquisiteapplicationsolutions.tis;

import android.content.Context;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

/**
 * Created by jnissley on 7/28/15.
 */
public class DateConvertClass {
    private static final String sDBName = "TIS.db";
    private static final int iVersionVal = 7;
    public Context oContext = null;

    public String GMTToLocal(String sDate) {
        String sReturnDate = "";
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        sdf.setTimeZone(TimeZone.getTimeZone("UTC"));
        try {
            //Create the datetime object
            Date dGMTDate = sdf.parse(sDate);
            //Use the phone time preferences to format the date and time
            DateFormat dateFormat = android.text.format.DateFormat.getDateFormat(oContext);
            DateFormat timeFormat = android.text.format.DateFormat.getTimeFormat(oContext);
            sReturnDate = dateFormat.format(dGMTDate);sReturnDate += " " + timeFormat.format(dGMTDate);
        } catch (ParseException ex) {
            DBLogs.insert("Date Exception: " + ex.toString(),
                    "DateConvertClass.GMTToLocal",
                    oContext, sDBName, iVersionVal);
            sReturnDate = "Invalid";
        }
        return sReturnDate;
    }

    /*
    This is primarily used for the job tracking time. It is in mysql timestamp format so
    it is more easily handled formatting for the time view on the web site.
     */
    public String LocalToGMTTimeStamp(Date dInDate) {
        String sReturnDate = "";
        SimpleDateFormat sdfGMT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        sdfGMT.setTimeZone(TimeZone.getTimeZone("UTC"));
        sReturnDate = sdfGMT.format(dInDate);
        return sReturnDate;
    }

    public String LocalToGMTTimeStamp(String sDate, String sTime) {
        String sReturnDate = "";
        //Get the date format. Since we are using the short local date and time this is the command
        DateFormat sdDateFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT, Locale.getDefault());
        try {
            Date oDate = sdDateFormat.parse(sDate + " " + sTime);
            SimpleDateFormat sdfGMT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            sdfGMT.setTimeZone(TimeZone.getTimeZone("UTC"));
            sReturnDate = sdfGMT.format(oDate);
        } catch (ParseException ex) {
            DBLogs.insert("Date Exception: " + ex.toString(),
                    "DateConvertClass.LocalToGMTTimeStamp",
                    oContext, sDBName, iVersionVal);
            sReturnDate = "Invalid";
        }
        return sReturnDate;
    }
    /* this will format to the time string required for the database*/
    public String LocalToGMTDatabase(String sDate, String sTime) {

        String sReturnDate = "";
        //Get the date format. Since we are using the short local date and time this is the command
        DateFormat sdDateFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT, Locale.getDefault());
        try {
            Date oDate = sdDateFormat.parse(sDate + " " + sTime);
            SimpleDateFormat sdfGMT = new SimpleDateFormat("MM/dd/yyyy hh:mm a");
            sdfGMT.setTimeZone(TimeZone.getTimeZone("UTC"));
            sReturnDate = sdfGMT.format(oDate);
            sReturnDate = sReturnDate.replace("a.m.", "AM").replace("p.m.", "PM");
            sReturnDate = sReturnDate.replace("am", "AM").replace("pm", "PM");
        } catch (ParseException ex) {
            DBLogs.insert("Date Exception: " + ex.toString(),
                    "DateConvertClass.LocalToGMTDatabase",
                    oContext, sDBName, iVersionVal);
            sReturnDate = "Invalid";
        }
        return sReturnDate;
    }

    /* This is the format that will be used for all time date items placed into the database
       All timestamps should be gmt so we can always display the time correctly for the timezone
       the phone is in.
     */
    public String GMTTimestamp() {
        String sTimeStamp = "";
        //Get the epoch value for now
        long lEpochLocal = new Date().getTime();
        TimeZone tz = TimeZone.getDefault();
        Calendar cal = Calendar.getInstance(tz);
        //Get the milisecond offset between gmt and the phone time
        int offsetInMillis = tz.getOffset(cal.getTimeInMillis());
        long lEpochGMT = lEpochLocal - offsetInMillis;
        SimpleDateFormat sdfGMT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        sTimeStamp = sdfGMT.format(new Date(lEpochGMT));
        return sTimeStamp;
    }

    public String FormatDateOnly (int year, int month, int day) {
        String sReturnDate = "";
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        try {
            //Create the datetime object
            Date dDateOnly = sdf.parse(year + "-" + month + "-" + day);
            //Use the phone time preferences to format the date
            DateFormat dateFormat = android.text.format.DateFormat.getDateFormat(oContext);
            sReturnDate = dateFormat.format(dDateOnly);
        } catch (ParseException ex) {
            DBLogs.insert("Date Exception: " + ex.toString(),
                    "DateConvertClass.FormatDateOnly",
                    oContext, sDBName, iVersionVal);
            sReturnDate = "Invalid";
        }
        return sReturnDate;
    }

    public String FormatTimeOnly (int Hour, int Minute) {
        String sReturnTime = "";
        SimpleDateFormat sdf = new SimpleDateFormat("HH:mm");
        try {
            //Create the datetime object
            Date dTimeOnly = sdf.parse(Hour + ":" + Minute);
            //Use the phone time preferences to format the time
            DateFormat timeFormat = android.text.format.DateFormat.getTimeFormat(oContext);
            sReturnTime = timeFormat.format(dTimeOnly);
        } catch (ParseException ex) {
            DBLogs.insert("Date Exception: " + ex.toString(),
                    "DateConvertClass.FormatTimeOnly",
                    oContext, sDBName, iVersionVal);
            sReturnTime = "Invalid";
        }
        return sReturnTime;
    }
}
