package com.exquisiteapplicationsolutions.tis.activities;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.webkit.WebView;
import android.widget.Button;
import android.widget.TextView;

import com.exquisiteapplicationsolutions.tis.DBLogs;
import com.exquisiteapplicationsolutions.tis.DateConvertClass;
import com.exquisiteapplicationsolutions.tis.R;
import com.exquisiteapplicationsolutions.tis.syncClasses.SyncIntentService;
import com.exquisiteapplicationsolutions.tis.syncClasses.SyncTasks;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.File;


public class PickupOrderActivity extends AppCompatActivity {

    private static final String sDBName = "TIS.db";
    private static final int iVersionVal = 7;
    private Context oContext = null;
    private static String sUserID = "";
    private String sJobID = "";
    private String sJobDoc = "";


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        oContext = getApplicationContext();
        setContentView(R.layout.activity_pickup_order);
        SharedPreferences prefs = getSharedPreferences("TISSharedPrefs",
                Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = prefs.edit();
        String sLoggedInUserCompany = prefs.getString("LoggedInUserCompany", "No Value");
        sUserID = prefs.getString("UserID", "No Value");
        TextView otvUserName = (TextView) findViewById(R.id.tvUserName);
        otvUserName.setText(sLoggedInUserCompany.substring(0,sLoggedInUserCompany.indexOf('-')));
        sJobID = getIntent().getExtras().getString("JobID");
        sJobDoc = getIntent().getExtras().getString("JobDoc");
        Button btnAcceptDocument = (Button) findViewById(R.id.btnAcceptDocument);
        btnAcceptDocument.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                acceptDocument();
            }
        });

        Button btnCancelDocument = (Button) findViewById(R.id.btnCancelDocument);
        btnCancelDocument.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
               finish();
            }
        });
        showFile();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_pickup_order, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }
        if (id == R.id.action_logout) {
            finish();
            Intent i = new Intent(getApplicationContext(), TISActivity.class);
            startActivity(i);
            return true;
        }
        if (id == R.id.action_icon_meanings) {
            Intent i = new Intent(getApplicationContext(), HelpActivity.class);
            i.putExtra("ScreenID", "IconMeanings");
            startActivity(i);
            return true;
        }
        if (id == R.id.action_help) {
            Intent i = new Intent(getApplicationContext(), HelpActivity.class);
            i.putExtra("ScreenID", "JobsDetailActivity");
            startActivity(i);
            return true;
        }
        if (id == R.id.action_about) {
            Intent i = new Intent(getApplicationContext(), AboutActivity.class);
            startActivity(i);
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    protected void onResume() {
        super.onResume();
        // load the document in the webview
        showFile();

    }

    private void acceptDocument() {
        Boolean bRtnVal = false;
        String data = "";
        String sPUDelStatus = "Accepted Document";

        try {
            DateConvertClass oDateConvertClass = new DateConvertClass();
            oDateConvertClass.oContext = oContext;
            String sCurrentDateTime = oDateConvertClass.GMTTimestamp();
            JSONObject oDocStatus = new JSONObject();
            oDocStatus.put("jobID", sJobID);
            oDocStatus.put("userID", sUserID);
            oDocStatus.put("PUDelStatus", sPUDelStatus);
            oDocStatus.put("dateTime", sCurrentDateTime);
            // Now set up the sync queue and try to send now
            SyncTasks syncTasks = new SyncTasks();
            syncTasks.oContext = oContext;
            syncTasks.sRecType = "ORDERPU";
            syncTasks.sRecID = oDocStatus.toString();
            syncTasks.sDateTime = sCurrentDateTime;
            syncTasks.sQueued = "1"; //Set as queued so sync service will not pick it up
            syncTasks.sDateTimeQueued = sCurrentDateTime;
            syncTasks.sCompleted = "0";
            syncTasks.sDateTimeCompleted = "";
            long lRecID = syncTasks.write();
            Intent OrderPUIntent = new Intent(oContext, SyncIntentService.class);
            OrderPUIntent.putExtra("RecType", "ORDERPU");
            OrderPUIntent.putExtra("ID", Long.toString(lRecID));
            OrderPUIntent.putExtra("RecID", oDocStatus.toString());
            startService(OrderPUIntent);
        } catch (JSONException ex) {
            DBLogs.insert("JSON Error: " + ex.toString(),
                    "PickupOrderActivity.acceptDocument", oContext,
                    sDBName, iVersionVal);
        }

        finish();
    }

    private void showFile() {
        File filePath = oContext.getDir("jobs", Context.MODE_PRIVATE);
        File fFile = new File(filePath, sJobDoc);
        if (fFile.exists()) {
            WebView wvDocument = (WebView) findViewById(R.id.wvPickupOrder);
            wvDocument.loadUrl("file:///" + fFile.toString());
        } else {
            WebView wvDocument = (WebView) findViewById(R.id.wvPickupOrder);
            wvDocument.loadUrl("file:///android_asset/po_missing.htm");
        }
    }
}
