/**
 *
 */
package com.exquisiteapplicationsolutions.tis.syncClasses;

import android.content.ContentValues;
import android.content.Context;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;

import com.exquisiteapplicationsolutions.tis.DBLogs;
import com.exquisiteapplicationsolutions.tis.DBParameters;
import com.exquisiteapplicationsolutions.tis.DateConvertClass;
import com.exquisiteapplicationsolutions.tis.TISDBHelper;
import com.exquisiteapplicationsolutions.tis.webServices.SyncJson;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;

/**
 * @author jcairns
 */
public class TISCommon  {
    private static final String sDBName = "TIS.db";
    private static final int iVersionVal = 7;

    /*public static boolean isOnline() {
        try {
            Socket soc = new Socket();
            soc.connect(new InetSocketAddress("transportationis.com", 22), 1000);
            soc.close();
            Log.d("TISCommon.isOnline(): ", "Successfull");
            return true;
        } catch (Exception ex) {
            Log.d("TISCommon.isOnline(): ", ex.toString());
            return false;
        }
    }*/

    public static boolean isOnline(Context oContext) {
        Boolean bRtnVal = false;
        /*DBParameters oDBParameters = new DBParameters();

        // WebServer Request URL
        String serverURL = oDBParameters.readParameter(
                "REST_BASE_URL", oContext, sDBName,
                iVersionVal);

        serverURL += "isOnline.php";

        String data = "";

        BufferedReader reader = null;
        StringBuilder sb = new StringBuilder();
        // Send data
        try {

            // Defined URL  where to send data
            URL url = new URL(serverURL);

            // Send POST data request
            URLConnection conn = url.openConnection();
            conn.setDoOutput(true);
            OutputStreamWriter wr = new OutputStreamWriter(conn.getOutputStream());
            wr.write(data);
            wr.flush();

            // Get the server response
            reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
            String line = null;

            // Read Server Response
            while ((line = reader.readLine()) != null) {
                sb.append(line + "");
            }
            if (sb.toString().equals("success")) {
                bRtnVal = true;
            } else {
                bRtnVal = false;
            }
        } catch (Exception ex) {
            ex.printStackTrace();
            Log.e("isOnline Error:", ex.toString());
            String sErrorMsg = "isOnline Error: " + ex.toString();
            DBLogs.insert(sErrorMsg,"TISCommon.isOnline(Context)",
                    oContext, sDBName, iVersionVal);
            bRtnVal=false;
        } finally {
            try {
                reader.close();
            } catch (Exception ex) {
                String sErrorMsg = "isOnline Error reader.close(): " + ex.toString();
                DBLogs.insert(sErrorMsg,"TISCommon.isOnline(Context)",
                        oContext, sDBName, iVersionVal);
                bRtnVal=false;
            }
        }*/

        ConnectivityManager cm = (ConnectivityManager) oContext.getSystemService(oContext.CONNECTIVITY_SERVICE);
        NetworkInfo an = cm.getActiveNetworkInfo();
        return an != null && an.isConnected();
    }

    public static boolean uploadLogs(Context oContext) {
        boolean bRTNValue = false;
        ArrayList<ArrayList<String>> sLogList = null;
        DBParameters oDBParameters = new DBParameters();
        String sDriverID = oDBParameters.readParameter(
                "CurrentUserID", oContext, sDBName,
                iVersionVal);
        TISDBHelper oDB = new TISDBHelper(oContext, sDBName,
                null, iVersionVal);
        try {
            oDB.createDataBase();
            oDB.openDataBase();
            String sLogSQL = "select TimeDate, Class, Message from Logs";
            sLogList = oDB.selectRecordsFromDBList(
                    sLogSQL, null);
            if (sLogList != null) {
                bRTNValue = true;
                JSONArray oLogArray = new JSONArray();
                for (int iCounter = 0; iCounter < sLogList.size(); iCounter++) {
                    JSONObject oLogObject = new JSONObject();
                    ArrayList<String> tempList = sLogList.get(iCounter);
                    try {
                        oLogObject.put("DriverID", sDriverID);
                        oLogObject.put("TimeDate", tempList.get(0));
                        oLogObject.put("Class", tempList.get(1));
                        oLogObject.put("Message", tempList.get(2));
                        oLogArray.put(oLogObject);
                    } catch (JSONException ex) {
                        ex.printStackTrace();
                        DBLogs.insert("Error: " + ex.toString(),
                                "TISCommon.uploadLogs", oContext,
                                sDBName, iVersionVal);
                        bRTNValue = false;
                    }
                }
                if (bRTNValue) {
                    //Here is where we do the sync
                    SyncJson oSyncLogItems = new SyncJson();
                    oSyncLogItems.oContext = oContext;
                    oSyncLogItems.sendString = oLogArray.toString();
                    oSyncLogItems.webserviceName = "inslogsWS.php";
                    String sResponse = oSyncLogItems.SyncData();
                    if (sResponse.toUpperCase().equals("SUCCESS")) {
                        bRTNValue = true;
                        oDB.deleteAllRecords("Logs");
                    } else {
                        bRTNValue = false;
                    }
                }
            }
        } catch (IOException ex) {
            DBLogs.insert("Error: " + ex.toString(),
                    "TISCommon.uploadLogs", oContext,
                    sDBName, iVersionVal);
        } finally {
            oDB.close();
        }
        return bRTNValue;
    }

    public static void cleanSyncTable(Context oContext) {
        TISDBHelper oDB = new TISDBHelper(oContext, sDBName, null, iVersionVal);
        try {
            oDB.createDataBase();
            oDB.openDataBase();
            String sWhereClause = "Completed='1'";
            oDB.deleteRecordInDB("SyncTasks", sWhereClause);
        } catch (Exception ex) {
            DBLogs.insert("Database Exception " + ex.getMessage(),
                    "TISCommon.cleanSyncTable",
                    oContext, sDBName, iVersionVal);
        } finally {
            oDB.close();
        }

    }

    // Clean the DVIR database. Delete any that are over a week old
    public static void cleanDVIRTable(Context oContext) {
        String sDVIRDaysToKeep = "7";
        DateConvertClass oDateConvertClass = new DateConvertClass();
        oDateConvertClass.oContext = oContext;
        String sCurrentDateTime = oDateConvertClass.GMTTimestamp();
        try {
            DBParameters oDBParameters = new DBParameters();
            sDVIRDaysToKeep = oDBParameters.readParameter("DVIR_Keep_Days",
                    oContext, sDBName, iVersionVal);
        } catch (Exception e) {

        }
        TISDBHelper oDB = new TISDBHelper(oContext, sDBName, null, iVersionVal);
        try {
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date dvrDate = dateFormat.parse(sCurrentDateTime);
            long ldayMillis = 86400000;
            Date lastWeek = new Date(dvrDate.getTime() - (ldayMillis * Integer.parseInt(sDVIRDaysToKeep)));
            String slastWeek = dateFormat.format(lastWeek);
            oDB.createDataBase();
            oDB.openDataBase();
            String sDVIRSQL = "select DVIRNo, DVIRDateTime from DVIREntered " +
                "where DVIRDateTime < '" + slastWeek + "'";
            oDB.openDataBase();
            ArrayList<ArrayList<String>> dvirArray = oDB.selectRecordsFromDBList(sDVIRSQL, null);
            if (dvirArray.size() > 0) {
                for (ArrayList<String> sValue : dvirArray) {
                    String sDVIRNumber = sValue.get(0);
                    String sWhereClause = "DVIRNo='" + sDVIRNumber + "' ";
                    oDB.deleteRecordInDB("DVIREntered", sWhereClause);
                    oDB.deleteRecordInDB("DVIRFieldValues", sWhereClause);
                }
            }
        } catch (Exception ex) {
            DBLogs.insert("Database Exception " + ex.getMessage(),
                    "TISCommon.cleanDVIRTable",
                    oContext, sDBName, iVersionVal);
        } finally {
            oDB.close();
        }
    }

    // Clean the DVIR database. Delete any that are over a week old
    public static void cleanJobsTable(Context oContext) {
        String sJobsDaysToKeep = "7";
        DateConvertClass oDateConvertClass = new DateConvertClass();
        oDateConvertClass.oContext = oContext;
        String sCurrentDateTime = oDateConvertClass.GMTTimestamp();
        try {
            DBParameters oDBParameters = new DBParameters();
            sJobsDaysToKeep = oDBParameters.readParameter("JOBS_Keep_Days",
                    oContext, sDBName, iVersionVal);
        } catch (Exception e) {
            DBLogs.insert("Database Exception " + e.getMessage(),
                    "TISCommon.cleanJobsTable",
                    oContext, sDBName, iVersionVal);
        }
        TISDBHelper oDB = new TISDBHelper(oContext, sDBName, null, iVersionVal);
        try {
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date dvrDate = dateFormat.parse(sCurrentDateTime);
            long ldayMillis = 86400000;
            Date fromDate = new Date(dvrDate.getTime() - (ldayMillis * Integer.parseInt(sJobsDaysToKeep)));
            String sfromDate = dateFormat.format(fromDate);
            oDB.createDataBase();
            oDB.openDataBase();
            String sJobsSQL = "select job_id, pickup_order_doc_name from jobs " +
                    "where date_time < '" + sfromDate + "' and job_status_id not in (3,4,5)";
            ArrayList<ArrayList<String>> jobsArray = oDB.selectRecordsFromDBList(sJobsSQL, null);
            if (jobsArray.size() > 0) {
                for (ArrayList<String> sValue : jobsArray) {
                    String sJob_id = sValue.get(0);
                    String sJobDoc = sValue.get(1);
                    String sWhereClause = "job_id='" + sJob_id + "' ";
                    oDB.deleteRecordInDB("Jobs", sWhereClause);
                    //Delete the pickup  order doc if it exists
                    if (sJobDoc.length() > 2) {
                        File filePath = oContext.getDir("jobs", Context.MODE_PRIVATE);
                        File fFullpath = new File(filePath, sJobDoc);
                        fFullpath.delete();
                    }
                }
            }
        } catch (Exception ex) {
            DBLogs.insert("Database Exception " + ex.getMessage(),
                    "TISCommon.cleanJobsTable",
                    oContext, sDBName, iVersionVal);
        } finally {
            oDB.close();
        }
    }

    public static void updateParameters(Context oContext) {
        //Here we will update the parameters that are controled from the server
        SyncJson oGetParameters = new SyncJson();
        oGetParameters.oContext = oContext;
        oGetParameters.sendString = "";
        oGetParameters.webserviceName = "getParameters.php";
        String sResponse = oGetParameters.SyncData();
        if (sResponse != "[]") {
            TISDBHelper oDB = new TISDBHelper(oContext, sDBName,
                    null, iVersionVal);
            JSONArray oJsonArray = null;
            try {
                oJsonArray = new JSONArray(sResponse);
            } catch(JSONException ex) {
                //
            }
            try {
                oDB.createDataBase();
                oDB.openDataBase();
                for (int iCounter = 0; iCounter < oJsonArray.length(); iCounter++) {
                    JSONObject json = oJsonArray.getJSONObject(iCounter);
                    ContentValues oValues = new ContentValues();
                    oValues.put("Value", json.getString("Value"));
                    String sWhere = "Name='" + json.getString("Name") + "'";
                    oDB.updateRecordsInDB("Parameters", sWhere, oValues);
                }
            } catch (IOException | JSONException ex) {
                DBLogs.insert("Database Exception " + ex.getMessage(),
                        "TISCommon.updateParameters",
                        oContext, sDBName, iVersionVal);
            } finally {
                oDB.close();
            }
        } else {
            DBLogs.insert("No values received",
                    "TISCommon.updateParameters",
                    oContext, sDBName, iVersionVal);
        }
    }

}
